bayespy.inference.vmp.nodes.gaussian.GaussianDistribution.random
================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianDistribution.random